@@ -1,9 +1,16 @@
 import inspect
+import sys
 
 from future.utils import raise_with_traceback
+from six import integer_types, string_types
 
+if sys.version_info[0] >= 3:
+    type_types = type
+else:
+    # These shenanigans are to support old-style classes in py27
+    import new  # pylint: disable=import-error
 
-from six import string_types
+    type_types = (type, new.classobj)  # pylint: disable=undefined-variable
 
 
 class CheckError(Exception):
@@ -22,18 +29,28 @@ class NotImplementedCheckError(CheckError):
     pass
 
 
-def _param_type_mismatch_exception(obj, ttype, param_name):
+def _param_type_mismatch_exception(obj, ttype, param_name, additional_message=None):
     if isinstance(ttype, tuple):
         type_names = sorted([t.__name__ for t in ttype])
         return ParameterCheckError(
-            'Param "{name}" is not one of {type_names}. Got {obj} which is type {obj_type}.'.format(
-                name=param_name, obj=repr(obj), type_names=type_names, obj_type=type(obj)
+            'Param "{name}" is not one of {type_names}. Got {obj} which is type {obj_type}.'
+            '{additional_message}'.format(
+                name=param_name,
+                obj=repr(obj),
+                type_names=type_names,
+                obj_type=type(obj),
+                additional_message=' ' + additional_message if additional_message else '',
             )
         )
     else:
         return ParameterCheckError(
-            'Param "{name}" is not a {type}. Got {obj} which is type {obj_type}.'.format(
-                name=param_name, obj=repr(obj), type=ttype.__name__, obj_type=type(obj)
+            'Param "{name}" is not a {type}. Got {obj} which is type {obj_type}.'
+            '{additional_message}'.format(
+                name=param_name,
+                obj=repr(obj),
+                type=ttype.__name__,
+                obj_type=type(obj),
+                additional_message=' ' + additional_message if additional_message else '',
             )
         )
 
@@ -86,14 +103,14 @@ def _param_invariant_exception(param_name, desc):
 
 
 def failed(desc):
-    if not _is_str(desc):
+    if not is_str(desc):
         raise_with_traceback(CheckError('desc argument must be a string'))
 
     raise_with_traceback(CheckError('Failure condition: {desc}'.format(desc=desc)))
 
 
 def not_implemented(desc):
-    if not _is_str(desc):
+    if not is_str(desc):
         raise_with_traceback(CheckError('desc argument must be a string'))
 
     raise_with_traceback(NotImplementedCheckError('Not implemented: {desc}'.format(desc=desc)))
@@ -105,6 +122,13 @@ def inst(obj, ttype, desc=None):
     return obj
 
 
+def subclass(obj, superclass, desc=None):
+    if not issubclass(obj, superclass):
+        raise_with_traceback(_type_mismatch_error(obj, superclass, desc))
+
+    return obj
+
+
 def is_callable(obj, desc=None):
     if not callable(obj):
         if desc:
@@ -152,9 +176,13 @@ def param_invariant(condition, param_name, desc=None):
         raise_with_traceback(_param_invariant_exception(param_name, desc))
 
 
-def inst_param(obj, param_name, ttype):
+def inst_param(obj, param_name, ttype, additional_message=None):
     if not isinstance(obj, ttype):
-        raise_with_traceback(_param_type_mismatch_exception(obj, ttype, param_name))
+        raise_with_traceback(
+            _param_type_mismatch_exception(
+                obj, ttype, param_name, additional_message=additional_message
+            )
+        )
     return obj
 
 
@@ -177,13 +205,13 @@ def opt_callable_param(obj, param_name, default=None):
 
 
 def int_param(obj, param_name):
-    if not isinstance(obj, int):
+    if not isinstance(obj, integer_types):
         raise_with_traceback(_param_type_mismatch_exception(obj, int, param_name))
     return obj
 
 
 def int_value_param(obj, value, param_name):
-    if not isinstance(obj, int):
+    if not isinstance(obj, integer_types):
         raise_with_traceback(_param_type_mismatch_exception(obj, int, param_name))
     if obj != value:
         raise_with_traceback(
@@ -193,7 +221,7 @@ def int_value_param(obj, value, param_name):
 
 
 def opt_int_param(obj, param_name):
-    if obj is not None and not isinstance(obj, int):
+    if obj is not None and not isinstance(obj, integer_types):
         raise_with_traceback(_param_type_mismatch_exception(obj, int, param_name))
     return obj
 
@@ -204,18 +232,30 @@ def float_param(obj, param_name):
     return obj
 
 
+def opt_numeric_param(obj, param_name):
+    if obj is not None and not isinstance(obj, (int, float)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (int, float), param_name))
+    return obj
+
+
+def numeric_param(obj, param_name):
+    if not isinstance(obj, (int, float)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (int, float), param_name))
+    return obj
+
+
 def opt_float_param(obj, param_name):
     if obj is not None and not isinstance(obj, float):
         raise_with_traceback(_param_type_mismatch_exception(obj, float, param_name))
     return obj
 
 
-def _is_str(obj):
+def is_str(obj):
     return isinstance(obj, string_types)
 
 
 def str_param(obj, param_name):
-    if not _is_str(obj):
+    if not is_str(obj):
         raise_with_traceback(_param_type_mismatch_exception(obj, str, param_name))
     return obj
 
@@ -255,8 +295,12 @@ def is_list(obj_list, of_type=None, desc=None):
 
 
 def list_param(obj_list, param_name, of_type=None):
-    if not isinstance(obj_list, list):
-        raise_with_traceback(_param_type_mismatch_exception(obj_list, list, param_name))
+    from dagster.utils import frozenlist
+
+    if not isinstance(obj_list, (frozenlist, list)):
+        raise_with_traceback(
+            _param_type_mismatch_exception(obj_list, (frozenlist, list), param_name)
+        )
 
     if not of_type:
         return obj_list
@@ -265,8 +309,8 @@ def list_param(obj_list, param_name, of_type=None):
 
 
 def set_param(obj_set, param_name, of_type=None):
-    if not isinstance(obj_set, set):
-        raise_with_traceback(_param_type_mismatch_exception(obj_set, set, param_name))
+    if not isinstance(obj_set, (frozenset, set)):
+        raise_with_traceback(_param_type_mismatch_exception(obj_set, (frozenset, set), param_name))
 
     if not of_type:
         return obj_set
@@ -280,6 +324,17 @@ def tuple_param(obj, param_name):
     return obj
 
 
+def matrix_param(matrix, param_name, of_type=None):
+    matrix = list_param(matrix, param_name, of_type=list)
+    if not matrix:
+        raise_with_traceback(CheckError('You must pass a list of lists. Received an empty list.'))
+    for sublist in matrix:
+        sublist = list_param(sublist, 'sublist_{}'.format(param_name), of_type=of_type)
+        if len(sublist) != len(matrix[0]):
+            raise_with_traceback(CheckError('All sublists in matrix must have the same length'))
+    return matrix
+
+
 def opt_tuple_param(obj, param_name, default=None):
     if obj is not None and not isinstance(obj, tuple):
         raise_with_traceback(_param_type_mismatch_exception(obj, tuple, param_name))
@@ -347,8 +402,12 @@ def opt_list_param(obj_list, param_name, of_type=None):
     If the of_type argument is provided, also ensures that list items conform to the type specified
     by of_type.
     '''
-    if obj_list is not None and not isinstance(obj_list, list):
-        raise_with_traceback(_param_type_mismatch_exception(obj_list, list, param_name))
+    from dagster.utils import frozenlist
+
+    if obj_list is not None and not isinstance(obj_list, (frozenlist, list)):
+        raise_with_traceback(
+            _param_type_mismatch_exception(obj_list, (frozenlist, list), param_name)
+        )
     if not obj_list:
         return []
     if not of_type:
@@ -364,8 +423,8 @@ def opt_set_param(obj_set, param_name, of_type=None):
     If the of_type argument is provided, also ensures that list items conform to the type specified
     by of_type.
     '''
-    if obj_set is not None and not isinstance(obj_set, set):
-        raise_with_traceback(_param_type_mismatch_exception(obj_set, set, param_name))
+    if obj_set is not None and not isinstance(obj_set, (frozenset, set)):
+        raise_with_traceback(_param_type_mismatch_exception(obj_set, (frozenset, set), param_name))
     if not obj_set:
         return set()
     if not of_type:
@@ -380,8 +439,12 @@ def opt_nullable_list_param(obj_list, param_name, of_type=None):
     If the of_type argument is provided, also ensures that list items conform to the type specified
     by of_type.
     '''
-    if obj_list is not None and not isinstance(obj_list, list):
-        raise_with_traceback(_param_type_mismatch_exception(obj_list, list, param_name))
+    from dagster.utils import frozenlist
+
+    if obj_list is not None and not isinstance(obj_list, (frozenlist, list)):
+        raise_with_traceback(
+            _param_type_mismatch_exception(obj_list, (frozenlist, list), param_name)
+        )
     if not obj_list:
         return None if obj_list is None else []
     if not of_type:
@@ -428,8 +491,10 @@ def dict_param(obj, param_name, key_type=None, value_type=None):
     '''Ensures argument obj is a native Python dictionary, raises an exception if not, and otherwise
     returns obj.
     '''
-    if not isinstance(obj, dict):
-        raise_with_traceback(_param_type_mismatch_exception(obj, dict, param_name))
+    from dagster.utils import frozendict
+
+    if not isinstance(obj, (frozendict, dict)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (frozendict, dict), param_name))
 
     if not (key_type or value_type):
         return obj
@@ -441,8 +506,10 @@ def opt_dict_param(obj, param_name, key_type=None, value_type=None, value_class=
     '''Ensures argument obj is either a dictionary or None; if the latter, instantiates an empty
     dictionary.
     '''
-    if obj is not None and not isinstance(obj, dict):
-        raise_with_traceback(_param_type_mismatch_exception(obj, dict, param_name))
+    from dagster.utils import frozendict
+
+    if obj is not None and not isinstance(obj, (frozendict, dict)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (frozendict, dict), param_name))
 
     if not obj:
         return {}
@@ -455,8 +522,10 @@ def opt_dict_param(obj, param_name, key_type=None, value_type=None, value_class=
 def opt_nullable_dict_param(obj, param_name, key_type=None, value_type=None, value_class=None):
     '''Ensures argument obj is either a dictionary or None;
     '''
-    if obj is not None and not isinstance(obj, dict):
-        raise_with_traceback(_param_type_mismatch_exception(obj, dict, param_name))
+    from dagster.utils import frozendict
+
+    if obj is not None and not isinstance(obj, (frozendict, dict)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (frozendict, dict), param_name))
 
     if not obj:
         return None if obj is None else {}
@@ -493,7 +562,7 @@ def opt_two_dim_dict_param(obj, param_name, key_type=string_types, value_type=No
 
 
 def type_param(obj, param_name):
-    if not isinstance(obj, type):
+    if not isinstance(obj, type_types):
         raise_with_traceback(_not_type_param_subclass_mismatch_exception(obj, param_name))
     return obj
 
@@ -595,6 +664,8 @@ def opt_list_elem(ddict, key):
 
 
 def dict_elem(ddict, key):
+    from dagster.utils import frozendict
+
     dict_param(ddict, 'ddict')
     str_param(key, 'key')
 
@@ -604,12 +675,14 @@ def dict_elem(ddict, key):
         )
 
     value = ddict[key]
-    if not isinstance(value, dict):
-        raise_with_traceback(_element_check_error(key, value, ddict, dict))
+    if not isinstance(value, (frozendict, dict)):
+        raise_with_traceback(_element_check_error(key, value, ddict, (frozendict, dict)))
     return value
 
 
 def opt_dict_elem(ddict, key):
+    from dagster.utils import frozendict
+
     dict_param(ddict, 'ddict')
     str_param(key, 'key')
 
@@ -618,7 +691,7 @@ def opt_dict_elem(ddict, key):
     if value is None:
         return {}
 
-    if not isinstance(value, dict):
+    if not isinstance(value, (frozendict, dict)):
         raise_with_traceback(_element_check_error(key, value, ddict, list))
 
     return value
@@ -641,7 +714,7 @@ def opt_str_elem(ddict, key):
     value = ddict.get(key)
     if value is None:
         return None
-    if not _is_str(value):
+    if not is_str(value):
         raise_with_traceback(_element_check_error(key, value, ddict, str))
     return value
 
@@ -651,6 +724,16 @@ def str_elem(ddict, key):
     str_param(key, 'key')
 
     value = ddict[key]
-    if not _is_str(value):
+    if not is_str(value):
         raise_with_traceback(_element_check_error(key, value, ddict, str))
     return value
+
+
+def class_param(obj, param_name):
+    if not inspect.isclass(obj):
+        return ParameterCheckError(
+            'Param "{name}" is not a class. Got {obj} which is type {obj_type}.'.format(
+                name=param_name, obj=repr(obj), obj_type=type(obj),
+            )
+        )
+    return obj
