@@ -1,16 +1,17 @@
+import sys
 from collections import defaultdict
 from contextlib import contextmanager
-import sys
 
 import pytest
 
 from dagster import check
 from dagster.check import (
-    ParameterCheckError,
-    ElementCheckError,
     CheckError,
+    ElementCheckError,
     NotImplementedCheckError,
+    ParameterCheckError,
 )
+from dagster.utils import frozendict, frozenlist
 
 
 def test_int_param():
@@ -74,6 +75,7 @@ def test_opt_float_param():
 
 def test_list_param():
     assert check.list_param([], 'list_param') == []
+    assert check.list_param(frozenlist(), 'list_param') == []
 
     with pytest.raises(ParameterCheckError):
         check.list_param(None, 'list_param')
@@ -84,6 +86,7 @@ def test_list_param():
 
 def test_set_param():
     assert check.set_param(set(), 'set_param') == set()
+    assert check.set_param(frozenset(), 'set_param') == set()
 
     with pytest.raises(ParameterCheckError):
         check.set_param(None, 'set_param')
@@ -158,6 +161,7 @@ def test_typed_is_list():
 def test_opt_list_param():
     assert check.opt_list_param(None, 'list_param') == []
     assert check.opt_list_param([], 'list_param') == []
+    assert check.opt_list_param(frozenlist(), 'list_param') == []
     obj_list = [1]
     assert check.list_param(obj_list, 'list_param') == obj_list
 
@@ -174,6 +178,7 @@ def test_opt_list_param():
 def test_opt_set_param():
     assert check.opt_set_param(None, 'set_param') == set()
     assert check.opt_set_param(set(), 'set_param') == set()
+    assert check.opt_set_param(frozenset(), 'set_param') == set()
     assert check.opt_set_param({3}, 'set_param') == {3}
 
     with pytest.raises(ParameterCheckError):
@@ -189,6 +194,7 @@ def test_opt_set_param():
 def test_opt_nullable_list_param():
     assert check.opt_nullable_list_param(None, 'list_param') is None
     assert check.opt_nullable_list_param([], 'list_param') == []
+    assert check.opt_nullable_list_param(frozenlist(), 'list_param') == []
     obj_list = [1]
     assert check.opt_nullable_list_param(obj_list, 'list_param') == obj_list
 
@@ -223,6 +229,7 @@ def test_opt_typed_list_param():
 
 def test_dict_param():
     assert check.dict_param({}, 'dict_param') == {}
+    assert check.dict_param(frozendict(), 'dict_param') == {}
     ddict = {'a': 2}
     assert check.dict_param(ddict, 'dict_param') == ddict
 
@@ -315,6 +322,7 @@ def test_opt_dict_param_with_type():
 def test_opt_dict_param():
     assert check.opt_dict_param(None, 'opt_dict_param') == {}
     assert check.opt_dict_param({}, 'opt_dict_param') == {}
+    assert check.opt_dict_param(frozendict(), 'opt_dict_param') == {}
     ddict = {'a': 2}
     assert check.opt_dict_param(ddict, 'opt_dict_param') == ddict
 
@@ -337,10 +345,11 @@ def test_opt_dict_param():
 def test_opt_nullable_dict_param():
     assert check.opt_nullable_dict_param(None, 'opt_nullable_dict_param') is None
     assert check.opt_nullable_dict_param({}, 'opt_nullable_dict_param') == {}
+    assert check.opt_nullable_dict_param(frozendict(), 'opt_nullable_dict_param') == {}
     ddict = {'a': 2}
     assert check.opt_nullable_dict_param(ddict, 'opt_nullable_dict_param') == ddict
 
-    class Foo:
+    class Foo(object):
         pass
 
     class Bar(Foo):
@@ -740,6 +749,28 @@ def test_tuple_param():
         assert check.tuple_param('kdjfkd', 'something')
 
 
+def test_matrix_param():
+    assert check.matrix_param([[1, 2], [2, 3]], 'something')
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param(None, 'something')
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param([1, 2, 4], 'something')
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param([], 'something')
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param([[1, 2], 3], 'soemthing')
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param([[1, 2], [3.0, 4.1]], 'something', of_type=int)
+
+    with pytest.raises(CheckError):
+        assert check.matrix_param([[1, 2], [2, 3, 4]], 'something')
+
+
 def test_opt_tuple_param():
     assert check.opt_tuple_param((1, 2), 'something')
     assert check.opt_tuple_param(None, 'something') is None
