@@ -1,6 +1,4 @@
 from dagster import (
-    Dict,
-    Field,
     Int,
     ModeDefinition,
     PipelineDefinition,
@@ -9,10 +7,9 @@ from dagster import (
     String,
     check,
 )
-
-from dagster.core.definitions import create_environment_type
-from dagster.core.types import config
 from dagster.cli.config_scaffolder import scaffold_pipeline_config, scaffold_type
+from dagster.config import config_type
+from dagster.core.definitions import create_environment_type
 
 
 def fail_me():
@@ -20,11 +17,11 @@ def fail_me():
 
 
 def test_scalars():
-    assert scaffold_type(config.Int.inst()) == 0
-    assert scaffold_type(config.String.inst()) == ''
-    assert scaffold_type(config.Path.inst()) == 'path/to/something'
-    assert scaffold_type(config.Bool.inst()) is True
-    assert scaffold_type(config.Any.inst()) == 'AnyType'
+    assert scaffold_type(config_type.Int()) == 0
+    assert scaffold_type(config_type.String()) == ''
+    assert scaffold_type(config_type.Path()) == 'path/to/something'
+    assert scaffold_type(config_type.Bool()) is True
+    assert scaffold_type(config_type.Any()) == 'AnyType'
 
 
 def test_basic_solids_config(snapshot):
@@ -35,7 +32,7 @@ def test_basic_solids_config(snapshot):
                 name='required_field_solid',
                 input_defs=[],
                 output_defs=[],
-                config_field=Field(Dict(fields={'required_int': Field(Int)})),
+                config={'required_int': Int},
                 compute_fn=lambda *_args: fail_me(),
             )
         ],
@@ -43,11 +40,11 @@ def test_basic_solids_config(snapshot):
 
     env_config_type = create_environment_type(pipeline_def)
 
-    assert env_config_type.fields['solids'].is_optional is False
+    assert env_config_type.fields['solids'].is_required
     solids_config_type = env_config_type.fields['solids'].config_type
-    assert solids_config_type.fields['required_field_solid'].is_optional is False
+    assert solids_config_type.fields['required_field_solid'].is_required
     required_solid_config_type = solids_config_type.fields['required_field_solid'].config_type
-    assert required_solid_config_type.fields['config'].is_optional is False
+    assert required_solid_config_type.fields['config'].is_required
 
     assert set(env_config_type.fields['loggers'].config_type.fields.keys()) == set(['console'])
 
@@ -55,7 +52,7 @@ def test_basic_solids_config(snapshot):
 
     assert set(console_logger_config_type.config_type.fields.keys()) == set(['config'])
 
-    assert console_logger_config_type.config_type.fields['config'].is_optional
+    assert console_logger_config_type.config_type.fields['config'].is_required is False
 
     console_logger_config_config_type = console_logger_config_type.config_type.fields[
         'config'
@@ -63,7 +60,7 @@ def test_basic_solids_config(snapshot):
 
     assert set(console_logger_config_config_type.fields.keys()) == set(['log_level', 'name'])
 
-    snapshot.assert_match(scaffold_pipeline_config(pipeline_def, skip_optional=False))
+    snapshot.assert_match(scaffold_pipeline_config(pipeline_def, skip_non_required=False))
 
 
 def dummy_resource(config_field):
@@ -76,16 +73,10 @@ def test_two_modes(snapshot):
         solid_defs=[],
         mode_defs=[
             ModeDefinition(
-                'mode_one',
-                resource_defs={
-                    'value': dummy_resource(Field(Dict({'mode_one_field': Field(String)})))
-                },
+                'mode_one', resource_defs={'value': dummy_resource({'mode_one_field': String})},
             ),
             ModeDefinition(
-                'mode_two',
-                resource_defs={
-                    'value': dummy_resource(Field(Dict({'mode_two_field': Field(Int)})))
-                },
+                'mode_two', resource_defs={'value': dummy_resource({'mode_two_field': Int})},
             ),
         ],
     )
@@ -93,11 +84,11 @@ def test_two_modes(snapshot):
     snapshot.assert_match(scaffold_pipeline_config(pipeline_def, mode='mode_one'))
 
     snapshot.assert_match(
-        scaffold_pipeline_config(pipeline_def, mode='mode_one', skip_optional=False)
+        scaffold_pipeline_config(pipeline_def, mode='mode_one', skip_non_required=False)
     )
 
     snapshot.assert_match(scaffold_pipeline_config(pipeline_def, mode='mode_two'))
 
     snapshot.assert_match(
-        scaffold_pipeline_config(pipeline_def, mode='mode_two', skip_optional=False)
+        scaffold_pipeline_config(pipeline_def, mode='mode_two', skip_non_required=False)
     )
