@@ -1,33 +1,34 @@
 # encoding: utf-8
 # py27 compat
 
+import re
+from datetime import datetime
+
 import pytest
 
 from dagster import (
     Any,
     DagsterInvalidDefinitionError,
+    DagsterInvariantViolationError,
     DependencyDefinition,
     Field,
     InputDefinition,
+    Output,
     OutputDefinition,
     PipelineDefinition,
-    Output,
+    ScheduleDefinition,
     execute_pipeline,
+    execute_solid,
     lambda_solid,
+    pipeline,
+    schedules,
     solid,
 )
-
-from dagster.core.errors import DagsterInvariantViolationError
+from dagster.core.definitions.decorators import daily_schedule, hourly_schedule, monthly_schedule
 from dagster.core.utility_solids import define_stub_solid
 
 # This file tests a lot of parameter name stuff, so these warnings are spurious
-# pylint: disable=unused-variable, unused-argument
-
-
-def execute_isolated_solid(solid_def, environment_dict=None):
-    return execute_pipeline(
-        PipelineDefinition(name='test', solid_defs=[solid_def]), environment_dict=environment_dict
-    )
+# pylint: disable=unused-variable, unused-argument, redefined-outer-name
 
 
 def test_no_parens_solid():
@@ -37,7 +38,7 @@ def test_no_parens_solid():
     def hello_world():
         called['yup'] = True
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert called['yup']
 
@@ -49,7 +50,7 @@ def test_empty_solid():
     def hello_world():
         called['yup'] = True
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert called['yup']
 
@@ -59,11 +60,10 @@ def test_solid():
     def hello_world(_context):
         return {'foo': 'bar'}
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_one_output():
@@ -71,11 +71,10 @@ def test_solid_one_output():
     def hello_world():
         return {'foo': 'bar'}
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_yield():
@@ -83,11 +82,10 @@ def test_solid_yield():
     def hello_world(_context):
         yield Output(value={'foo': 'bar'})
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_result_return():
@@ -95,11 +93,10 @@ def test_solid_result_return():
     def hello_world(_context):
         return Output(value={'foo': 'bar'})
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_with_explicit_empty_outputs():
@@ -108,7 +105,7 @@ def test_solid_with_explicit_empty_outputs():
         return 'foo'
 
     with pytest.raises(DagsterInvariantViolationError) as exc_info:
-        result = execute_isolated_solid(hello_world)
+        result = execute_solid(hello_world)
 
     assert (
         'Error in solid hello_world: Unexpectedly returned output foo of type '
@@ -126,12 +123,10 @@ def test_solid_with_implicit_single_output():
     def hello_world(_context):
         return 'foo'
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    solid_result = result.solid_result_list[0]
-    assert solid_result.output_value() == 'foo'
+    assert result.output_value() == 'foo'
 
 
 def test_solid_return_list_instead_of_multiple_results():
@@ -140,7 +135,7 @@ def test_solid_return_list_instead_of_multiple_results():
         return ['foo', 'bar']
 
     with pytest.raises(DagsterInvariantViolationError) as exc_info:
-        result = execute_isolated_solid(hello_world)
+        result = execute_solid(hello_world)
 
     assert 'unexpectedly returned output [\'foo\', \'bar\']' in str(exc_info.value)
 
@@ -150,11 +145,10 @@ def test_lambda_solid_with_name():
     def hello_world():
         return {'foo': 'bar'}
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_with_name():
@@ -162,11 +156,10 @@ def test_solid_with_name():
     def hello_world(_context):
         return {'foo': 'bar'}
 
-    result = execute_isolated_solid(hello_world)
+    result = execute_solid(hello_world)
 
     assert result.success
-    assert len(result.solid_result_list) == 1
-    assert result.solid_result_list[0].output_value()['foo'] == 'bar'
+    assert result.output_value()['foo'] == 'bar'
 
 
 def test_solid_with_input():
@@ -275,12 +268,12 @@ def test_any_config_field():
     called = {}
     conf_value = 234
 
-    @solid(config_field=Field(Any))
+    @solid(config=Field(Any))
     def hello_world(context):
         assert context.solid_config == conf_value
         called['yup'] = True
 
-    result = execute_isolated_solid(
+    result = execute_solid(
         hello_world, environment_dict={'solids': {'hello_world': {'config': conf_value}}}
     )
 
@@ -296,3 +289,183 @@ def test_solid_no_arg():
         @solid
         def noop():
             return
+
+
+def test_scheduler():
+    @schedules
+    def define_scheduler():
+        return [
+            ScheduleDefinition(
+                name="my_schedule",
+                cron_schedule="* * * * *",
+                pipeline_name="test_pipeline",
+                environment_dict={},
+            )
+        ]
+
+
+def test_schedule_decorators_sanity():
+    @solid
+    def do_nothing(_):
+        pass
+
+    @pipeline
+    def foo_pipeline():
+        do_nothing()
+
+    @monthly_schedule(
+        pipeline_name='foo_pipeline',
+        execution_day_of_month=3,
+        start_date=datetime(year=2019, month=1, day=1),
+    )
+    def monthly_foo_schedule():
+        return {}
+
+    @daily_schedule(
+        pipeline_name='foo_pipeline', start_date=datetime(year=2019, month=1, day=1),
+    )
+    def daily_foo_schedule():
+        return {}
+
+    @hourly_schedule(
+        pipeline_name='foo_pipeline', start_date=datetime(year=2019, month=1, day=1),
+    )
+    def hourly_foo_schedule():
+        return {}
+
+
+def test_schedule_decorators_bad():
+    @solid
+    def do_nothing(_):
+        pass
+
+    @pipeline
+    def foo_pipeline():
+        do_nothing()
+
+    with pytest.raises(DagsterInvalidDefinitionError):
+
+        @monthly_schedule(
+            pipeline_name='foo_pipeline',
+            execution_day_of_month=32,
+            start_date=datetime(year=2019, month=1, day=1),
+        )
+        def monthly_foo_schedule_over():
+            return {}
+
+    with pytest.raises(DagsterInvalidDefinitionError):
+
+        @monthly_schedule(
+            pipeline_name='foo_pipeline',
+            execution_day_of_month=0,
+            start_date=datetime(year=2019, month=1, day=1),
+        )
+        def monthly_foo_schedule_under():
+            return {}
+
+
+def test_solid_docstring():
+    @solid
+    def foo_solid(_):
+        '''FOO_DOCSTRING'''
+        return
+
+    @lambda_solid
+    def bar_solid():
+        '''BAR_DOCSTRING'''
+        return
+
+    @solid(name='baz')
+    def baz_solid(_):
+        '''BAZ_DOCSTRING'''
+        return
+
+    @lambda_solid(name='quux')
+    def quux_solid():
+        '''QUUX_DOCSTRING'''
+        return
+
+    assert foo_solid.__doc__ == 'FOO_DOCSTRING'
+    assert bar_solid.__doc__ == 'BAR_DOCSTRING'
+    assert baz_solid.__doc__ == 'BAZ_DOCSTRING'
+    assert quux_solid.__doc__ == 'QUUX_DOCSTRING'
+
+
+def test_solid_yields_single_bare_value():
+    @solid
+    def return_iterator(_):
+        yield 1
+
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match=re.escape('Compute function for solid return_iterator yielded a value of type <')
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'> rather than an instance of Output, Materialization, or ExpectationResult. '
+            'Values yielded by solids must be wrapped in one of these types. If your solid has a '
+            'single output and yields no other events, you may want to use `return` instead of '
+            '`yield` in the body of your solid compute function. If you are already using '
+            '`return`, and you expected to return a value of type <'
+        )
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'>, you may be inadvertently returning a generator rather than the value you '
+            'expected.'
+        ),
+    ):
+        result = execute_solid(return_iterator)
+
+
+def test_solid_yields_multiple_bare_values():
+    @solid
+    def return_iterator(_):
+        yield 1
+        yield 2
+
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match=re.escape('Compute function for solid return_iterator yielded a value of type <')
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'> rather than an instance of Output, Materialization, or ExpectationResult. '
+            'Values yielded by solids must be wrapped in one of these types. If your solid has a '
+            'single output and yields no other events, you may want to use `return` instead of '
+            '`yield` in the body of your solid compute function. If you are already using '
+            '`return`, and you expected to return a value of type <'
+        )
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'>, you may be inadvertently returning a generator rather than the value you '
+            'expected.'
+        ),
+    ):
+        result = execute_solid(return_iterator)
+
+
+def test_solid_returns_iterator():
+    def iterator():
+        for i in range(3):
+            yield i
+
+    @solid
+    def return_iterator(_):
+        return iterator()
+
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match=re.escape('Compute function for solid return_iterator yielded a value of type <')
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'> rather than an instance of Output, Materialization, or ExpectationResult. '
+            'Values yielded by solids must be wrapped in one of these types. If your solid has a '
+            'single output and yields no other events, you may want to use `return` instead of '
+            '`yield` in the body of your solid compute function. If you are already using '
+            '`return`, and you expected to return a value of type <'
+        )
+        + r'(class|type)'
+        + re.escape(
+            ' \'int\'>, you may be inadvertently returning a generator rather than the value you '
+            'expected.'
+        ),
+    ):
+        result = execute_solid(return_iterator)
