@@ -1,17 +1,17 @@
 from dagster import (
-    DagsterEventType,
     DependencyDefinition,
     InputDefinition,
     Int,
+    Output,
     OutputDefinition,
     PipelineDefinition,
-    Output,
-    RunConfig,
     lambda_solid,
     solid,
 )
-
 from dagster.core.execution.api import create_execution_plan, execute_plan
+from dagster.core.instance import DagsterInstance
+from dagster.core.storage.pipeline_run import PipelineRun
+from dagster.core.utils import make_new_run_id
 
 
 def define_two_int_pipeline():
@@ -40,21 +40,30 @@ def test_execution_plan_simple_two_steps():
     assert execution_plan.get_step_by_key('return_one.compute')
     assert execution_plan.get_step_by_key('add_one.compute')
 
-    step_events = execute_plan(execution_plan)
+    pipeline_run = PipelineRun.create_empty_run(pipeline_def.name, make_new_run_id())
+    events = execute_plan(
+        execution_plan, pipeline_run=pipeline_run, instance=DagsterInstance.ephemeral()
+    )
     # start, out, success, start, input, out, success
-    assert len(step_events) == 7
+    assert [e.event_type_value for e in events] == [
+        'ENGINE_EVENT',
+        'STEP_START',
+        'STEP_OUTPUT',
+        'STEP_SUCCESS',
+        'STEP_START',
+        'STEP_INPUT',
+        'STEP_OUTPUT',
+        'STEP_SUCCESS',
+        'ENGINE_EVENT',
+    ]
 
-    assert step_events[1].step_key == 'return_one.compute'
-    assert step_events[1].is_successful_output
-    assert step_events[1].step_output_data.value_repr == '1'
+    output_events = [e for e in events if e.event_type_value == 'STEP_OUTPUT']
 
-    assert step_events[2].event_type == DagsterEventType.STEP_SUCCESS
-    assert step_events[3].event_type == DagsterEventType.STEP_START
-    assert step_events[4].event_type == DagsterEventType.STEP_INPUT
+    assert output_events[0].step_key == 'return_one.compute'
+    assert output_events[0].is_successful_output
 
-    assert step_events[5].step_key == 'add_one.compute'
-    assert step_events[5].is_successful_output
-    assert step_events[5].step_output_data.value_repr == '2'
+    assert output_events[1].step_key == 'add_one.compute'
+    assert output_events[1].is_successful_output
 
 
 def test_execution_plan_two_outputs():
@@ -67,14 +76,15 @@ def test_execution_plan_two_outputs():
 
     execution_plan = create_execution_plan(pipeline_def)
 
-    step_events = execute_plan(execution_plan)
+    pipeline_run = PipelineRun.create_empty_run(pipeline_def.name, make_new_run_id())
+    step_events = execute_plan(
+        execution_plan, pipeline_run=pipeline_run, instance=DagsterInstance.ephemeral()
+    )
 
-    assert step_events[1].step_key == 'return_one_two.compute'
-    assert step_events[1].step_output_data.value_repr == '1'
-    assert step_events[1].step_output_data.output_name == 'num_one'
     assert step_events[2].step_key == 'return_one_two.compute'
-    assert step_events[2].step_output_data.value_repr == '2'
-    assert step_events[2].step_output_data.output_name == 'num_two'
+    assert step_events[2].step_output_data.output_name == 'num_one'
+    assert step_events[3].step_key == 'return_one_two.compute'
+    assert step_events[3].step_output_data.output_name == 'num_two'
 
 
 def test_reentrant_execute_plan():
@@ -89,9 +99,15 @@ def test_reentrant_execute_plan():
     pipeline_def = PipelineDefinition(name='has_tag_pipeline', solid_defs=[has_tag])
     execution_plan = create_execution_plan(pipeline_def)
 
-    step_events = execute_plan(execution_plan, run_config=RunConfig(tags={'foo': 'bar'}))
+    pipeline_run = PipelineRun.create_empty_run(
+        pipeline_def.name, make_new_run_id(), tags={'foo': 'bar'}
+    )
+
+    step_events = execute_plan(
+        execution_plan, pipeline_run=pipeline_run, instance=DagsterInstance.ephemeral()
+    )
 
     assert called['yup']
-    assert len(step_events) == 3
+    assert len(step_events) == 5
 
-    assert step_events[0].logging_tags['foo'] == 'bar'
+    assert step_events[1].logging_tags['foo'] == 'bar'
