@@ -3,38 +3,31 @@ import pytest
 from dagster import (
     Any,
     DependencyDefinition,
-    Dict,
     Field,
     InputDefinition,
     Int,
     ModeDefinition,
-    NamedDict,
     OutputDefinition,
-    ResourceDefinition,
     PipelineDefinition,
+    ResourceDefinition,
     SolidDefinition,
     SolidInvocation,
     String,
     execute_pipeline,
     lambda_solid,
+    pipeline,
+    solid,
 )
-from dagster.core.definitions import create_environment_type, create_environment_schema
+from dagster.config.config_type import ConfigTypeKind
+from dagster.config.errors import DagsterEvaluateConfigValueError
+from dagster.core.definitions import create_environment_schema, create_environment_type
 from dagster.core.definitions.environment_configs import (
-    define_resource_cls,
-    define_expectations_config_cls,
+    EnvironmentClassCreationData,
     define_solid_config_cls,
     define_solid_dictionary_cls,
-    EnvironmentClassCreationData,
 )
-from dagster.core.types.evaluator.errors import DagsterEvaluateConfigValueError
-from dagster.core.system_config.objects import (
-    construct_solid_dictionary,
-    EnvironmentConfig,
-    ExpectationsConfig,
-    SolidConfig,
-)
-from dagster.core.test_utils import throwing_evaluate_config_value
-from dagster.core.types.evaluator import evaluate_config
+from dagster.core.system_config.objects import EnvironmentConfig, SolidConfig
+from dagster.core.test_utils import throwing_validate_config_value
 from dagster.loggers import default_loggers
 
 
@@ -43,33 +36,11 @@ def create_creation_data(pipeline_def):
         pipeline_def.name,
         pipeline_def.solids,
         pipeline_def.dependency_structure,
-        mode_definition=None,
+        pipeline_def.mode_definition,
         logger_defs=default_loggers(),
     )
 
 
-def test_resource_config_any():
-    resource_type = define_resource_cls(
-        'Parent', 'Foo', ResourceDefinition(lambda: None, Field(Any))
-    ).inst()
-
-    assert resource_type.type_attributes.is_system_config
-
-    assert throwing_evaluate_config_value(resource_type, {'config': 1}) == {'config': 1}
-
-
-def test_default_expectations():
-    expect_config_type = define_expectations_config_cls('some_name').inst()
-    assert (
-        ExpectationsConfig(**throwing_evaluate_config_value(expect_config_type, {})).evaluate
-        is True
-    )
-    assert (
-        ExpectationsConfig(**throwing_evaluate_config_value(expect_config_type, None)).evaluate
-        is True
-    )
-
-
 def test_all_types_provided():
     pipeline_def = PipelineDefinition(
         name='pipeline',
@@ -80,16 +51,9 @@ def test_all_types_provided():
                 resource_defs={
                     'some_resource': ResourceDefinition(
                         lambda: None,
-                        config_field=Field(
-                            NamedDict(
-                                'SomeModeNamedDict',
-                                {
-                                    'with_default_int': Field(
-                                        Int, is_optional=True, default_value=23434
-                                    )
-                                },
-                            )
-                        ),
+                        config={
+                            'with_default_int': Field(Int, is_required=False, default_value=23434)
+                        },
                     )
                 },
             )
@@ -99,151 +63,109 @@ def test_all_types_provided():
     environment_schema = create_environment_schema(pipeline_def)
 
     all_types = list(environment_schema.all_config_types())
-    type_names = set(t.name for t in all_types)
-    assert 'SomeModeNamedDict' in type_names
-    assert 'Pipeline.Mode.SomeMode.Environment' in type_names
-    assert 'Pipeline.Mode.SomeMode.Resources.SomeResource' in type_names
+
+    matching_types = [
+        tt
+        for tt in all_types
+        if tt.kind == ConfigTypeKind.STRICT_SHAPE and 'with_default_int' in tt.fields.keys()
+    ]
+    assert len(matching_types) == 1
 
 
 def test_provided_default_on_resources_config():
-    pipeline_def = PipelineDefinition(
+    @solid(name='some_solid', input_defs=[], output_defs=[])
+    def some_solid(_):
+        return None
+
+    @pipeline(
         mode_defs=[
             ModeDefinition(
                 name='some_mode',
                 resource_defs={
                     'some_resource': ResourceDefinition(
                         resource_fn=lambda: None,
-                        config_field=Field(
-                            Dict(
-                                {
-                                    'with_default_int': Field(
-                                        Int, is_optional=True, default_value=23434
-                                    )
-                                }
-                            )
-                        ),
+                        config={
+                            'with_default_int': Field(Int, is_required=False, default_value=23434)
+                        },
                     )
                 },
             )
-        ],
-        solid_defs=[
-            SolidDefinition(
-                name='some_solid', input_defs=[], output_defs=[], compute_fn=lambda *args: None
-            )
-        ],
+        ]
     )
+    def pipeline_def():
+        some_solid()
 
     env_type = create_environment_type(pipeline_def)
-    assert env_type.type_attributes.is_system_config
     some_resource_field = env_type.fields['resources'].config_type.fields['some_resource']
-    assert some_resource_field.is_optional
+    assert some_resource_field.is_required is False
 
     some_resource_config_field = some_resource_field.config_type.fields['config']
-    assert some_resource_config_field.is_optional
+    assert some_resource_config_field.is_required is False
     assert some_resource_config_field.default_value == {'with_default_int': 23434}
 
     assert some_resource_field.default_value == {'config': {'with_default_int': 23434}}
 
-    value = EnvironmentConfig.from_dict(throwing_evaluate_config_value(env_type, {}))
+    value = EnvironmentConfig.build(pipeline_def, {})
     assert value.resources == {'some_resource': {'config': {'with_default_int': 23434}}}
 
 
 def test_default_environment():
-    pipeline_def = PipelineDefinition(
-        solid_defs=[
-            SolidDefinition(
-                name='some_solid', input_defs=[], output_defs=[], compute_fn=lambda *args: None
-            )
-        ]
-    )
+    @solid(name='some_solid', input_defs=[], output_defs=[])
+    def some_solid(_):
+        return None
 
-    env_obj = EnvironmentConfig.from_dict(
-        throwing_evaluate_config_value(create_environment_type(pipeline_def), {})
-    )
+    @pipeline
+    def pipeline_def():
+        some_solid()
 
-    assert env_obj.expectations.evaluate is True
-
-
-def test_resource_def_config_errors():
-    takes_int_resource_def = ResourceDefinition(
-        resource_fn=lambda: None, config_field=Field(Dict({'required_int': Field(Int)}))
-    )
-
-    resource_type = define_resource_cls('Parent', 'takes_int', takes_int_resource_def).inst()
-
-    assert not evaluate_config(resource_type, 1).success
-    assert not evaluate_config(resource_type, {}).success
-    assert not evaluate_config(resource_type, {'config': {}}).success
-    assert evaluate_config(resource_type, {'config': {'required_int': 2}}).success
-    assert not evaluate_config(resource_type, {'config': {'required_int': 'kdjfkd'}}).success
+    assert EnvironmentConfig.build(pipeline_def, {})
 
 
 def test_solid_config():
-    solid_config_type = define_solid_config_cls('kdjfkd', Field(Int), None, None).inst()
-    solid_inst = throwing_evaluate_config_value(solid_config_type, {'config': 1})
+    solid_config_type = define_solid_config_cls(Field(Int), None, None)
+    solid_inst = throwing_validate_config_value(solid_config_type, {'config': 1})
     assert solid_inst['config'] == 1
-    assert solid_config_type.inst().type_attributes.is_system_config
-
-
-def test_expectations_config():
-    expectations_config_type = define_expectations_config_cls('ksjdfkd').inst()
-    expectations = ExpectationsConfig(
-        **throwing_evaluate_config_value(expectations_config_type, {'evaluate': True})
-    )
-
-    assert isinstance(expectations, ExpectationsConfig)
-    assert expectations.evaluate is True
-
-    assert ExpectationsConfig(
-        **throwing_evaluate_config_value(expectations_config_type, {'evaluate': False})
-    ) == ExpectationsConfig(evaluate=False)
 
 
 def test_solid_dictionary_type():
     pipeline_def = define_test_solids_config_pipeline()
 
-    solid_dict_type = define_solid_dictionary_cls(
-        'foobar', pipeline_def.solids, pipeline_def.dependency_structure, pipeline_def.name
-    ).inst()
-
-    value = construct_solid_dictionary(
-        throwing_evaluate_config_value(
-            solid_dict_type,
-            {'int_config_solid': {'config': 1}, 'string_config_solid': {'config': 'bar'}},
-        )
+    env_obj = EnvironmentConfig.build(
+        pipeline_def,
+        {'solids': {'int_config_solid': {'config': 1}, 'string_config_solid': {'config': 'bar'}},},
     )
 
+    value = env_obj.solids
+
     assert set(['int_config_solid', 'string_config_solid']) == set(value.keys())
     assert value == {'int_config_solid': SolidConfig(1), 'string_config_solid': SolidConfig('bar')}
 
-    assert solid_dict_type.type_attributes.is_system_config
-
-    for specific_solid_config_field in solid_dict_type.fields.values():
-        specific_solid_config_type = specific_solid_config_field.config_type
-        assert specific_solid_config_type.type_attributes.is_system_config
-        user_config_field = specific_solid_config_field.config_type.fields['config']
-        assert user_config_field.config_type.type_attributes.is_system_config is False
-
 
 def define_test_solids_config_pipeline():
-    return PipelineDefinition(
-        solid_defs=[
-            SolidDefinition(
-                name='int_config_solid',
-                config_field=Field(Int, is_optional=True),
-                input_defs=[],
-                output_defs=[],
-                compute_fn=lambda *args: None,
-            ),
-            SolidDefinition(
-                name='string_config_solid',
-                config_field=Field(String, is_optional=True),
-                input_defs=[],
-                output_defs=[],
-                compute_fn=lambda *args: None,
-            ),
-        ]
+    @solid(
+        name='int_config_solid',
+        config=Field(Int, is_required=False),
+        input_defs=[],
+        output_defs=[],
     )
+    def int_config_solid(_):
+        return None
+
+    @solid(
+        name='string_config_solid',
+        config=Field(String, is_required=False),
+        input_defs=[],
+        output_defs=[],
+    )
+    def string_config_solid(_):
+        return None
+
+    @pipeline
+    def pipeline_def():
+        int_config_solid()
+        string_config_solid()
+
+    return pipeline_def
 
 
 def assert_has_fields(dtype, *fields):
@@ -259,44 +181,37 @@ def test_solid_configs_defaults():
 
     int_solid_field = solids_field.config_type.fields['int_config_solid']
 
-    assert int_solid_field.is_optional
+    assert int_solid_field.is_required is False
     # TODO: this is the test case the exposes the default dodginess
+    # https://github.com/dagster-io/dagster/issues/1990
     assert int_solid_field.default_provided
 
     assert_has_fields(int_solid_field.config_type, 'config')
 
     int_solid_config_field = int_solid_field.config_type.fields['config']
 
-    assert int_solid_config_field.is_optional
+    assert int_solid_config_field.is_required is False
     assert not int_solid_config_field.default_provided
 
 
 def test_solid_dictionary_some_no_config():
-    pipeline_def = PipelineDefinition(
-        solid_defs=[
-            SolidDefinition(
-                name='int_config_solid',
-                config_field=Field(Int),
-                input_defs=[],
-                output_defs=[],
-                compute_fn=lambda *args: None,
-            ),
-            SolidDefinition(
-                name='no_config_solid', input_defs=[], output_defs=[], compute_fn=lambda *args: None
-            ),
-        ]
-    )
+    @solid(name='int_config_solid', config=Int, input_defs=[], output_defs=[])
+    def int_config_solid(_):
+        return None
 
-    solid_dict_type = define_solid_dictionary_cls(
-        'foobar', pipeline_def.solids, pipeline_def.dependency_structure, pipeline_def.name
-    ).inst()
+    @solid(name='no_config_solid', input_defs=[], output_defs=[])
+    def no_config_solid(_):
+        return None
 
-    value = construct_solid_dictionary(
-        throwing_evaluate_config_value(solid_dict_type, {'int_config_solid': {'config': 1}})
-    )
+    @pipeline
+    def pipeline_def():
+        int_config_solid()
+        no_config_solid()
 
-    assert set(['int_config_solid']) == set(value.keys())
-    assert value == {'int_config_solid': SolidConfig(1)}
+    env = EnvironmentConfig.build(pipeline_def, {'solids': {'int_config_solid': {'config': 1}}})
+
+    assert {'int_config_solid', 'no_config_solid'} == set(env.solids.keys())
+    assert env.solids == {'int_config_solid': SolidConfig(1), 'no_config_solid': SolidConfig()}
 
 
 def test_whole_environment():
@@ -306,16 +221,14 @@ def test_whole_environment():
             ModeDefinition(
                 name='test_mode',
                 resource_defs={
-                    'test_resource': ResourceDefinition(
-                        resource_fn=lambda: None, config_field=Field(Any)
-                    )
+                    'test_resource': ResourceDefinition(resource_fn=lambda: None, config=Any)
                 },
             )
         ],
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(Int),
+                config=Int,
                 input_defs=[],
                 output_defs=[],
                 compute_fn=lambda *args: None,
@@ -326,52 +239,32 @@ def test_whole_environment():
         ],
     )
 
-    environment_type = create_environment_type(pipeline_def)
-
-    assert (
-        environment_type.fields['resources'].config_type.name
-        == 'SomePipeline.Mode.TestMode.Resources'
-    )
-    solids_type = environment_type.fields['solids'].config_type
-    assert solids_type.name == 'SomePipeline.SolidsConfigDictionary'
-    assert (
-        solids_type.fields['int_config_solid'].config_type.name
-        == 'SomePipeline.SolidConfig.IntConfigSolid'
-    )
-    assert (
-        environment_type.fields['expectations'].config_type.name
-        == 'SomePipeline.ExpectationsConfig'
-    )
-
-    env = EnvironmentConfig.from_dict(
-        throwing_evaluate_config_value(
-            environment_type,
-            {
-                'resources': {'test_resource': {'config': 1}},
-                'solids': {'int_config_solid': {'config': 123}},
-            },
-        )
+    env = EnvironmentConfig.build(
+        pipeline_def,
+        {
+            'resources': {'test_resource': {'config': 1}},
+            'solids': {'int_config_solid': {'config': 123}},
+        },
     )
 
     assert isinstance(env, EnvironmentConfig)
-    assert env.solids == {'int_config_solid': SolidConfig(123)}
-    assert env.expectations == ExpectationsConfig(evaluate=True)
+    assert env.solids == {'int_config_solid': SolidConfig(123), 'no_config_solid': SolidConfig()}
     assert env.resources == {'test_resource': {'config': 1}}
 
 
 def test_solid_config_error():
     pipeline_def = define_test_solids_config_pipeline()
     solid_dict_type = define_solid_dictionary_cls(
-        'slkdfjkjdsf', pipeline_def.solids, pipeline_def.dependency_structure, pipeline_def.name
-    ).inst()
+        pipeline_def.solids, pipeline_def.dependency_structure,
+    )
 
     int_solid_config_type = solid_dict_type.fields['int_config_solid'].config_type
 
-    with pytest.raises(DagsterEvaluateConfigValueError, match='Field "notconfig" is not defined'):
-        throwing_evaluate_config_value(int_solid_config_type, {'notconfig': 1})
+    with pytest.raises(DagsterEvaluateConfigValueError, match='Undefined field "notconfig"'):
+        throwing_validate_config_value(int_solid_config_type, {'notconfig': 1})
 
     with pytest.raises(DagsterEvaluateConfigValueError):
-        throwing_evaluate_config_value(int_solid_config_type, 1)
+        throwing_validate_config_value(int_solid_config_type, 1)
 
 
 def test_optional_solid_with_no_config():
@@ -383,7 +276,7 @@ def test_optional_solid_with_no_config():
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(Int),
+                config=Int,
                 input_defs=[],
                 output_defs=[],
                 compute_fn=lambda context, _inputs: _assert_config_none(context, 234),
@@ -409,7 +302,7 @@ def test_optional_solid_with_optional_scalar_config():
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(Int, is_optional=True),
+                config=Field(Int, is_required=False),
                 input_defs=[],
                 output_defs=[],
                 compute_fn=lambda context, _inputs: _assert_config_none(context, 234),
@@ -419,17 +312,13 @@ def test_optional_solid_with_optional_scalar_config():
 
     env_type = create_environment_type(pipeline_def)
 
-    assert env_type.fields['solids'].is_optional is True
+    assert env_type.fields['solids'].is_required is False
 
     solids_type = env_type.fields['solids'].config_type
 
-    assert solids_type.fields['int_config_solid'].is_optional is True
+    assert solids_type.fields['int_config_solid'].is_required is False
 
-    solids_default_obj = construct_solid_dictionary(throwing_evaluate_config_value(solids_type, {}))
-
-    assert solids_default_obj['int_config_solid'].config is None
-
-    env_obj = EnvironmentConfig.from_dict(throwing_evaluate_config_value(env_type, {}))
+    env_obj = EnvironmentConfig.build(pipeline_def, {})
 
     assert env_obj.solids['int_config_solid'].config is None
 
@@ -443,7 +332,7 @@ def test_optional_solid_with_required_scalar_config():
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(Int),
+                config=Int,
                 input_defs=[],
                 output_defs=[],
                 compute_fn=lambda context, _inputs: _assert_config_none(context, 234),
@@ -453,11 +342,11 @@ def test_optional_solid_with_required_scalar_config():
 
     env_type = create_environment_type(pipeline_def)
 
-    assert env_type.fields['solids'].is_optional is False
+    assert env_type.fields['solids'].is_required is True
 
     solids_type = env_type.fields['solids'].config_type
 
-    assert solids_type.fields['int_config_solid'].is_optional is False
+    assert solids_type.fields['int_config_solid'].is_required is True
 
     int_config_solid_type = solids_type.fields['int_config_solid'].config_type
 
@@ -465,7 +354,7 @@ def test_optional_solid_with_required_scalar_config():
 
     int_config_solid_config_field = int_config_solid_type.fields['config']
 
-    assert int_config_solid_config_field.is_optional is False
+    assert int_config_solid_config_field.is_required is True
 
     execute_pipeline(pipeline_def, {'solids': {'int_config_solid': {'config': 234}}})
 
@@ -476,7 +365,7 @@ def test_required_solid_with_required_subfield():
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(Dict({'required_field': Field(String)})),
+                config={'required_field': String},
                 input_defs=[],
                 output_defs=[],
                 compute_fn=lambda *_args: None,
@@ -486,30 +375,27 @@ def test_required_solid_with_required_subfield():
 
     env_type = create_environment_type(pipeline_def)
 
-    assert env_type.fields['solids'].is_optional is False
+    assert env_type.fields['solids'].is_required is True
     assert env_type.fields['solids'].config_type
 
     solids_type = env_type.fields['solids'].config_type
-    assert solids_type.fields['int_config_solid'].is_optional is False
+    assert solids_type.fields['int_config_solid'].is_required is True
     int_config_solid_type = solids_type.fields['int_config_solid'].config_type
-    assert int_config_solid_type.fields['config'].is_optional is False
+    assert int_config_solid_type.fields['config'].is_required is True
 
-    assert env_type.fields['execution'].is_optional
-    assert env_type.fields['expectations'].is_optional
+    assert env_type.fields['execution'].is_required is False
 
-    env_obj = EnvironmentConfig.from_dict(
-        throwing_evaluate_config_value(
-            env_type, {'solids': {'int_config_solid': {'config': {'required_field': 'foobar'}}}}
-        )
+    env_obj = EnvironmentConfig.build(
+        pipeline_def, {'solids': {'int_config_solid': {'config': {'required_field': 'foobar'}}}},
     )
 
     assert env_obj.solids['int_config_solid'].config['required_field'] == 'foobar'
 
     with pytest.raises(DagsterEvaluateConfigValueError):
-        throwing_evaluate_config_value(env_type, {'solids': {}})
+        throwing_validate_config_value(env_type, {'solids': {}})
 
     with pytest.raises(DagsterEvaluateConfigValueError):
-        throwing_evaluate_config_value(env_type, {})
+        throwing_validate_config_value(env_type, {})
 
 
 def test_optional_solid_with_optional_subfield():
@@ -518,8 +404,8 @@ def test_optional_solid_with_optional_subfield():
         solid_defs=[
             SolidDefinition(
                 name='int_config_solid',
-                config_field=Field(
-                    Dict({'optional_field': Field(String, is_optional=True)}), is_optional=True
+                config=Field(
+                    {'optional_field': Field(String, is_required=False)}, is_required=False
                 ),
                 input_defs=[],
                 output_defs=[],
@@ -529,9 +415,8 @@ def test_optional_solid_with_optional_subfield():
     )
 
     env_type = create_environment_type(pipeline_def)
-    assert env_type.fields['solids'].is_optional
-    assert env_type.fields['execution'].is_optional
-    assert env_type.fields['expectations'].is_optional
+    assert env_type.fields['solids'].is_required is False
+    assert env_type.fields['execution'].is_required is False
 
 
 def nested_field(config_type, *field_names):
@@ -553,8 +438,7 @@ def test_required_resource_with_required_subfield():
             ModeDefinition(
                 resource_defs={
                     'with_required': ResourceDefinition(
-                        resource_fn=lambda: None,
-                        config_field=Field(Dict({'required_field': Field(String)})),
+                        resource_fn=lambda: None, config={'required_field': String},
                     )
                 }
             )
@@ -562,9 +446,8 @@ def test_required_resource_with_required_subfield():
     )
 
     env_type = create_environment_type(pipeline_def)
-    assert env_type.fields['solids'].is_optional
-    assert env_type.fields['execution'].is_optional
-    assert env_type.fields['expectations'].is_optional
+    assert env_type.fields['solids'].is_required is False
+    assert env_type.fields['execution'].is_required is False
     assert env_type.fields['resources'].is_required
     assert nested_field(env_type, 'resources', 'with_required').is_required
     assert nested_field(env_type, 'resources', 'with_required', 'config').is_required
@@ -582,9 +465,7 @@ def test_all_optional_field_on_single_resource():
                 resource_defs={
                     'with_optional': ResourceDefinition(
                         resource_fn=lambda: None,
-                        config_field=Field(
-                            Dict({'optional_field': Field(String, is_optional=True)})
-                        ),
+                        config={'optional_field': Field(String, is_required=False)},
                     )
                 }
             )
@@ -592,15 +473,15 @@ def test_all_optional_field_on_single_resource():
     )
 
     env_type = create_environment_type(pipeline_def)
-    assert env_type.fields['solids'].is_optional
-    assert env_type.fields['execution'].is_optional
-    assert env_type.fields['expectations'].is_optional
-    assert env_type.fields['resources'].is_optional
-    assert nested_field(env_type, 'resources', 'with_optional').is_optional
-    assert nested_field(env_type, 'resources', 'with_optional', 'config').is_optional
-    assert nested_field(
-        env_type, 'resources', 'with_optional', 'config', 'optional_field'
-    ).is_optional
+    assert env_type.fields['solids'].is_required is False
+    assert env_type.fields['execution'].is_required is False
+    assert env_type.fields['resources'].is_required is False
+    assert nested_field(env_type, 'resources', 'with_optional').is_required is False
+    assert nested_field(env_type, 'resources', 'with_optional', 'config').is_required is False
+    assert (
+        nested_field(env_type, 'resources', 'with_optional', 'config', 'optional_field').is_required
+        is False
+    )
 
 
 def test_optional_and_required_context():
@@ -612,18 +493,10 @@ def test_optional_and_required_context():
                 name='mixed',
                 resource_defs={
                     'optional_resource': ResourceDefinition(
-                        lambda: None,
-                        config_field=Field(
-                            dagster_type=Dict(
-                                fields={'optional_field': Field(String, is_optional=True)}
-                            )
-                        ),
+                        lambda: None, config={'optional_field': Field(String, is_required=False)},
                     ),
                     'required_resource': ResourceDefinition(
-                        lambda: None,
-                        config_field=Field(
-                            dagster_type=Dict(fields={'required_field': Field(String)})
-                        ),
+                        lambda: None, config={'required_field': String},
                     ),
                 },
             )
@@ -631,17 +504,19 @@ def test_optional_and_required_context():
     )
 
     env_type = create_environment_type(pipeline_def)
-    assert env_type.fields['solids'].is_optional
+    assert env_type.fields['solids'].is_required is False
 
-    assert env_type.fields['execution'].is_optional
-    assert env_type.fields['expectations'].is_optional
+    assert env_type.fields['execution'].is_required is False
 
     assert nested_field(env_type, 'resources').is_required
-    assert nested_field(env_type, 'resources', 'optional_resource').is_optional
-    assert nested_field(env_type, 'resources', 'optional_resource', 'config').is_optional
-    assert nested_field(
-        env_type, 'resources', 'optional_resource', 'config', 'optional_field'
-    ).is_optional
+    assert nested_field(env_type, 'resources', 'optional_resource').is_required is False
+    assert nested_field(env_type, 'resources', 'optional_resource', 'config').is_required is False
+    assert (
+        nested_field(
+            env_type, 'resources', 'optional_resource', 'config', 'optional_field'
+        ).is_required
+        is False
+    )
 
     assert nested_field(env_type, 'resources', 'required_resource').is_required
     assert nested_field(env_type, 'resources', 'required_resource', 'config').is_required
@@ -649,10 +524,8 @@ def test_optional_and_required_context():
         env_type, 'resources', 'required_resource', 'config', 'required_field'
     ).is_required
 
-    env_obj = EnvironmentConfig.from_dict(
-        throwing_evaluate_config_value(
-            env_type, {'resources': {'required_resource': {'config': {'required_field': 'foo'}}}}
-        )
+    env_obj = EnvironmentConfig.build(
+        pipeline_def, {'resources': {'required_resource': {'config': {'required_field': 'foo'}}}},
     )
 
     assert env_obj.resources == {
@@ -726,7 +599,7 @@ def test_files_default_config():
     env_type = create_environment_type(pipeline_def)
     assert 'storage' in env_type.fields
 
-    config_value = throwing_evaluate_config_value(env_type, {})
+    config_value = throwing_validate_config_value(env_type, {})
 
     assert 'storage' not in config_value
 
@@ -737,6 +610,10 @@ def test_storage_in_memory_config():
     env_type = create_environment_type(pipeline_def)
     assert 'storage' in env_type.fields
 
-    config_value = throwing_evaluate_config_value(env_type, {'storage': {'in_memory': {}}})
+    config_value = throwing_validate_config_value(env_type, {'storage': {'in_memory': {}}})
 
     assert config_value['storage'] == {'in_memory': {}}
+
+
+def test_directly_init_environment_config():
+    EnvironmentConfig()
