@@ -1,10 +1,11 @@
 import pytest
 
 from dagster import (
+    DagsterInvalidConfigError,
     DependencyDefinition,
     InputDefinition,
+    List,
     OutputDefinition,
-    DagsterInvalidConfigError,
     PipelineDefinition,
     SolidInvocation,
     String,
@@ -69,7 +70,7 @@ def test_string_missing_inputs():
 
     assert exc_info.value.errors[0].message == (
         '''Missing required field "solids" at document config root. '''
-        '''Available Fields: "['execution', 'expectations', 'loggers', '''
+        '''Available Fields: "['execution', 'loggers', '''
         ''''resources', 'solids', 'storage']".'''
     )
 
@@ -102,3 +103,24 @@ def test_string_missing_input_collision():
     )
 
     assert 'yup' not in called
+
+
+def test_composite_input_type():
+    called = {}
+
+    @solid(input_defs=[InputDefinition('list_string_input', List[String])])
+    def str_as_input(_context, list_string_input):
+        assert list_string_input == ['foo']
+        called['yup'] = True
+
+    pipeline = PipelineDefinition(
+        name='test_string_from_inputs_pipeline', solid_defs=[str_as_input]
+    )
+
+    result = execute_pipeline(
+        pipeline,
+        {'solids': {'str_as_input': {'inputs': {'list_string_input': [{'value': 'foo'}]}}}},
+    )
+
+    assert result.success
+    assert called['yup']
