@@ -1,33 +1,34 @@
 import pytest
 
 from dagster import (
+    DagsterInstance,
     DagsterInvariantViolationError,
     DagsterStepOutputNotFoundError,
-    DependencyDefinition,
+    ExecutionTargetHandle,
     InputDefinition,
     Output,
     OutputDefinition,
-    PipelineDefinition,
-    SolidDefinition,
     execute_pipeline,
+    pipeline,
+    solid,
 )
 
 
 def test_multiple_outputs():
-    def _t_fn(*_args):
-        yield Output(output_name='output_one', value='foo')
-        yield Output(output_name='output_two', value='bar')
-
-    solid = SolidDefinition(
+    @solid(
         name='multiple_outputs',
         input_defs=[],
         output_defs=[OutputDefinition(name='output_one'), OutputDefinition(name='output_two')],
-        compute_fn=_t_fn,
     )
+    def multiple_outputs(_):
+        yield Output(output_name='output_one', value='foo')
+        yield Output(output_name='output_two', value='bar')
 
-    pipeline = PipelineDefinition(solid_defs=[solid])
+    @pipeline
+    def muptiple_outputs_pipeline():
+        multiple_outputs()
 
-    result = execute_pipeline(pipeline)
+    result = execute_pipeline(muptiple_outputs_pipeline)
     solid_result = result.solid_result_list[0]
 
     assert solid_result.solid.name == 'multiple_outputs'
@@ -35,101 +36,85 @@ def test_multiple_outputs():
     assert solid_result.output_value('output_two') == 'bar'
 
     with pytest.raises(
-        DagsterInvariantViolationError, match='not_defined not defined in solid multiple_outputs'
+        DagsterInvariantViolationError,
+        match="Output 'not_defined' not defined in solid 'multiple_outputs'",
     ):
         solid_result.output_value('not_defined')
 
 
 def test_wrong_multiple_output():
-    def _t_fn(*_args):
+    @solid(
+        name='multiple_outputs', input_defs=[], output_defs=[OutputDefinition(name='output_one')]
+    )
+    def multiple_outputs(_):
         yield Output(output_name='mismatch', value='foo')
 
-    solid = SolidDefinition(
-        name='multiple_outputs',
-        input_defs=[],
-        output_defs=[OutputDefinition(name='output_one')],
-        compute_fn=_t_fn,
-    )
-
-    pipeline = PipelineDefinition(solid_defs=[solid])
+    @pipeline
+    def wrong_multiple_outputs_pipeline():
+        multiple_outputs()
 
     with pytest.raises(DagsterInvariantViolationError):
-        execute_pipeline(pipeline)
+        execute_pipeline(wrong_multiple_outputs_pipeline)
 
 
 def test_multiple_outputs_of_same_name_disallowed():
     # make this illegal until it is supported
 
-    def _t_fn(*_args):
-        yield Output(output_name='output_one', value='foo')
-        yield Output(output_name='output_one', value='foo')
-
-    solid = SolidDefinition(
-        name='multiple_outputs',
-        input_defs=[],
-        output_defs=[OutputDefinition(name='output_one')],
-        compute_fn=_t_fn,
+    @solid(
+        name='multiple_outputs', input_defs=[], output_defs=[OutputDefinition(name='output_one')]
     )
+    def multiple_outputs(_):
+        yield Output(output_name='output_one', value='foo')
+        yield Output(output_name='output_one', value='foo')
 
-    pipeline = PipelineDefinition(solid_defs=[solid])
+    @pipeline
+    def muptiple_outputs_pipeline():
+        multiple_outputs()
 
     with pytest.raises(DagsterInvariantViolationError):
-        execute_pipeline(pipeline)
+        execute_pipeline(muptiple_outputs_pipeline)
 
 
-def test_multiple_outputs_only_emit_one():
-    def _t_fn(*_args):
-        yield Output(output_name='output_one', value='foo')
-
-    solid = SolidDefinition(
+def define_multi_out():
+    @solid(
         name='multiple_outputs',
         input_defs=[],
         output_defs=[
             OutputDefinition(name='output_one'),
-            OutputDefinition(name='output_two', is_optional=True),
+            OutputDefinition(name='output_two', is_required=False),
         ],
-        compute_fn=_t_fn,
     )
+    def multiple_outputs(_):
+        yield Output(output_name='output_one', value='foo')
 
-    called = {}
+    @solid(name='downstream_one', input_defs=[InputDefinition('some_input')], output_defs=[])
+    def downstream_one(_, some_input):
+        del some_input
 
-    def _compute_fn_one(*_args, **_kwargs):
-        called['one'] = True
-
-    downstream_one = SolidDefinition(
-        name='downstream_one',
-        input_defs=[InputDefinition('some_input')],
-        output_defs=[],
-        compute_fn=_compute_fn_one,
-    )
-
-    def _compute_fn_two(*_args, **_kwargs):
+    @solid
+    def downstream_two(_, some_input):
+        del some_input
         raise Exception('do not call me')
 
-    downstream_two = SolidDefinition(
-        name='downstream_two',
-        input_defs=[InputDefinition('some_input')],
-        output_defs=[],
-        compute_fn=_compute_fn_two,
-    )
+    @pipeline
+    def multiple_outputs_only_emit_one_pipeline():
+        output_one, output_two = multiple_outputs()
+        downstream_one(output_one)
+        downstream_two(output_two)
 
-    pipeline = PipelineDefinition(
-        solid_defs=[solid, downstream_one, downstream_two],
-        dependencies={
-            'downstream_one': {'some_input': DependencyDefinition(solid.name, output='output_one')},
-            'downstream_two': {'some_input': DependencyDefinition(solid.name, output='output_two')},
-        },
-    )
+    return multiple_outputs_only_emit_one_pipeline
 
-    result = execute_pipeline(pipeline)
+
+def test_multiple_outputs_only_emit_one():
+    result = execute_pipeline(define_multi_out())
     assert result.success
 
-    assert called['one']
     solid_result = result.result_for_solid('multiple_outputs')
     assert set(solid_result.output_values.keys()) == set(['output_one'])
 
     with pytest.raises(
-        DagsterInvariantViolationError, match='not_defined not defined in solid multiple_outputs'
+        DagsterInvariantViolationError,
+        match="Output 'not_defined' not defined in solid 'multiple_outputs'",
     ):
         solid_result.output_value('not_defined')
 
@@ -138,7 +123,45 @@ def test_multiple_outputs_only_emit_one():
 
     with pytest.raises(
         DagsterInvariantViolationError,
-        match='Try to get result for solid not_present in <<unnamed>>. No such solid.',
+        match=(
+            'Tried to get result for solid not_present in multiple_outputs_only_emit_one_pipeline. '
+            'No such top level solid.'
+        ),
+    ):
+        result.result_for_solid('not_present')
+
+    assert result.result_for_solid('downstream_two').skipped
+
+
+def test_multiple_outputs_only_emit_one_multiproc():
+    pipe = ExecutionTargetHandle.for_pipeline_python_file(
+        __file__, 'define_multi_out'
+    ).build_pipeline_definition()
+    result = execute_pipeline(
+        pipe,
+        environment_dict={'storage': {'filesystem': {}}, 'execution': {'multiprocess': {}}},
+        instance=DagsterInstance.local_temp(),
+    )
+    assert result.success
+
+    solid_result = result.result_for_solid('multiple_outputs')
+    assert set(solid_result.output_values.keys()) == set(['output_one'])
+
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match="Output 'not_defined' not defined in solid 'multiple_outputs'",
+    ):
+        solid_result.output_value('not_defined')
+
+    with pytest.raises(DagsterInvariantViolationError, match='Did not find result output_two'):
+        solid_result.output_value('output_two')
+
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match=(
+            'Tried to get result for solid not_present in multiple_outputs_only_emit_one_pipeline. '
+            'No such top level solid.'
+        ),
     ):
         result.result_for_solid('not_present')
 
@@ -146,17 +169,17 @@ def test_multiple_outputs_only_emit_one():
 
 
 def test_missing_non_optional_output_fails():
-    def _t_fn(*_args):
-        yield Output(output_name='output_one', value='foo')
-
-    solid = SolidDefinition(
+    @solid(
         name='multiple_outputs',
         input_defs=[],
         output_defs=[OutputDefinition(name='output_one'), OutputDefinition(name='output_two')],
-        compute_fn=_t_fn,
     )
+    def multiple_outputs(_):
+        yield Output(output_name='output_one', value='foo')
 
-    pipeline = PipelineDefinition(solid_defs=[solid])
+    @pipeline
+    def missing_non_optional_pipeline():
+        multiple_outputs()
 
     with pytest.raises(DagsterStepOutputNotFoundError):
-        execute_pipeline(pipeline)
+        execute_pipeline(missing_non_optional_pipeline)
