@@ -1,44 +1,37 @@
-# pylint: disable=no-value-for-parameter
-
 import dagster.check as check
-
 from dagster import (
     DependencyDefinition,
-    InProcessExecutorConfig,
     InputDefinition,
     Int,
+    List,
     ModeDefinition,
     MultiDependencyDefinition,
     Nothing,
+    Optional,
+    Output,
     OutputDefinition,
     PipelineDefinition,
     ResourceDefinition,
-    Output,
     RunConfig,
-    SolidInvocation,
+    String,
     execute_pipeline,
     execute_pipeline_iterator,
     lambda_solid,
     pipeline,
     solid,
 )
-
-from dagster.core.types import Optional, List, String
-
-from dagster.core.definitions import Solid, solids_in_topological_order
-from dagster.core.definitions.dependency import DependencyStructure
+from dagster.core.definitions import Solid
 from dagster.core.definitions.container import _create_adjacency_lists
-
+from dagster.core.definitions.dependency import DependencyStructure
 from dagster.core.execution.api import step_output_event_filter
 from dagster.core.execution.results import SolidExecutionResult
-
+from dagster.core.instance import DagsterInstance
 from dagster.core.utility_solids import (
-    define_stub_solid,
     create_root_solid,
     create_solid_with_deps,
+    define_stub_solid,
     input_set,
 )
-
 from dagster.utils.test import execute_solid_within_pipeline
 
 # protected members
@@ -74,12 +67,7 @@ def make_compute_fn():
 
 
 def _do_construct(solids, dependencies):
-    solids = {
-        s.name: Solid(
-            name=s.name, definition=s, resource_mapper_fn=SolidInvocation.default_resource_mapper_fn
-        )
-        for s in solids
-    }
+    solids = {s.name: Solid(name=s.name, definition=s) for s in solids}
     dependency_structure = DependencyStructure.from_definitions(solids, dependencies)
     return _create_adjacency_lists(list(solids.values()), dependency_structure)
 
@@ -159,7 +147,7 @@ def create_diamond_pipeline():
 
 
 def test_diamond_toposort():
-    assert [s.name for s in solids_in_topological_order(create_diamond_pipeline())] == [
+    assert [s.name for s in create_diamond_pipeline().solids_in_topological_order] == [
         'A_source',
         'A',
         'B',
@@ -312,13 +300,6 @@ def test_pipeline_name_threaded_through_context():
 
     assert result.success
 
-    for step_event in step_output_event_filter(
-        execute_pipeline_iterator(
-            PipelineDefinition(name="foobar", solid_defs=[assert_name_solid]), {}
-        )
-    ):
-        assert step_event.is_step_success
-
 
 def test_pipeline_subset():
     @lambda_solid
@@ -348,13 +329,6 @@ def test_pipeline_subset():
     assert len(subset_result.solid_result_list) == 1
     assert subset_result.result_for_solid('add_one').output_value() == 4
 
-    events = execute_pipeline_iterator(
-        pipeline_def.build_sub_pipeline(['add_one']), environment_dict=env_config
-    )
-
-    for step_event in step_output_event_filter(events):
-        assert step_event.is_step_success
-
 
 def test_pipeline_subset_with_multi_dependency():
     @lambda_solid
@@ -390,11 +364,6 @@ def test_pipeline_subset_with_multi_dependency():
     assert len(subset_result.solid_result_list) == 1
     assert pipeline_result.result_for_solid('noop').output_value() == 3
 
-    events = execute_pipeline_iterator(pipeline_def.build_sub_pipeline(['noop']))
-
-    for step_event in step_output_event_filter(events):
-        assert step_event.is_step_success
-
     subset_result = execute_pipeline(
         pipeline_def.build_sub_pipeline(['return_one', 'return_two', 'noop'])
     )
@@ -516,12 +485,10 @@ def test_pipeline_streaming_iterator():
 
     push_one_step_event = next(step_event_iterator)
     assert push_one_step_event.is_successful_output
-    assert push_one_step_event.step_output_data.value_repr == '1'
     assert events == [1]
 
     add_one_step_event = next(step_event_iterator)
     assert add_one_step_event.is_successful_output
-    assert add_one_step_event.step_output_data.value_repr == '2'
     assert events == [1, 2]
 
 
@@ -545,19 +512,20 @@ def test_pipeline_streaming_multiple_outputs():
 
     one_output_step_event = next(step_event_iterator)
     assert one_output_step_event.is_successful_output
-    assert one_output_step_event.step_output_data.value_repr == '1'
     assert one_output_step_event.step_output_data.output_name == 'one'
     assert events == [1]
 
     two_output_step_event = next(step_event_iterator)
     assert two_output_step_event.is_successful_output
-    assert two_output_step_event.step_output_data.value_repr == '2'
     assert two_output_step_event.step_output_data.output_name == 'two'
     assert events == [1, 2]
 
 
 def test_pipeline_init_failure():
-    stub_solid = define_stub_solid('stub', None)
+    @solid(required_resource_keys={'failing'})
+    def stub_solid(_):
+        return None
+
     env_config = {}
 
     def failing_resource_fn(*args, **kwargs):
@@ -574,13 +542,191 @@ def test_pipeline_init_failure():
         stub_solid()
 
     result = execute_pipeline(
-        failing_init_pipeline,
-        environment_dict=env_config,
-        run_config=RunConfig(executor_config=InProcessExecutorConfig(raise_on_error=False)),
+        failing_init_pipeline, environment_dict=dict(env_config), raise_on_error=False
     )
 
     assert result.success is False
-    assert len(result.event_list) == 1
-    event = result.event_list[0]
+    event = result.event_list[-1]
     assert event.event_type_value == 'PIPELINE_INIT_FAILURE'
     assert event.pipeline_init_failure_data
+
+
+def test_reexecution():
+    @lambda_solid
+    def return_one():
+        return 1
+
+    @lambda_solid
+    def add_one(num):
+        return num + 1
+
+    pipeline_def = PipelineDefinition(
+        solid_defs=[return_one, add_one],
+        dependencies={'add_one': {'num': DependencyDefinition('return_one')}},
+    )
+    instance = DagsterInstance.ephemeral()
+    pipeline_result = execute_pipeline(
+        pipeline_def, environment_dict={'storage': {'filesystem': {}}}, instance=instance
+    )
+    assert pipeline_result.success
+    assert pipeline_result.result_for_solid('add_one').output_value() == 2
+
+    reexecution_run_config = RunConfig(previous_run_id=pipeline_result.run_id)
+    reexecution_result = execute_pipeline(
+        pipeline_def,
+        environment_dict={'storage': {'filesystem': {}}},
+        run_config=reexecution_run_config,
+        instance=instance,
+    )
+
+    assert reexecution_result.success
+    assert len(reexecution_result.solid_result_list) == 2
+    assert reexecution_result.result_for_solid('return_one').output_value() == 1
+    assert reexecution_result.result_for_solid('add_one').output_value() == 2
+
+
+def test_single_step_reexecution():
+    @lambda_solid
+    def return_one():
+        return 1
+
+    @lambda_solid
+    def add_one(num):
+        return num + 1
+
+    pipeline_def = PipelineDefinition(
+        solid_defs=[return_one, add_one],
+        dependencies={'add_one': {'num': DependencyDefinition('return_one')}},
+    )
+    instance = DagsterInstance.ephemeral()
+    pipeline_result = execute_pipeline(
+        pipeline_def, environment_dict={'storage': {'filesystem': {}}}, instance=instance
+    )
+    assert pipeline_result.success
+    assert pipeline_result.result_for_solid('add_one').output_value() == 2
+
+    reexecution_result = execute_pipeline(
+        pipeline_def,
+        environment_dict={'storage': {'filesystem': {}}},
+        run_config=RunConfig(
+            previous_run_id=pipeline_result.run_id, step_keys_to_execute=['add_one.compute']
+        ),
+        instance=instance,
+    )
+
+    assert reexecution_result.success
+    assert reexecution_result.result_for_solid('return_one').output_value() == None
+    assert reexecution_result.result_for_solid('add_one').output_value() == 2
+
+
+def test_two_step_reexecution():
+    @lambda_solid
+    def return_one():
+        return 1
+
+    @lambda_solid
+    def add_one(num):
+        return num + 1
+
+    @pipeline
+    def two_step_reexec():
+        add_one(add_one(return_one()))
+
+    instance = DagsterInstance.ephemeral()
+    pipeline_result = execute_pipeline(
+        two_step_reexec, environment_dict={'storage': {'filesystem': {}}}, instance=instance
+    )
+    assert pipeline_result.success
+    assert pipeline_result.result_for_solid('add_one_2').output_value() == 3
+
+    reexecution_result = execute_pipeline(
+        two_step_reexec,
+        environment_dict={'storage': {'filesystem': {}}},
+        run_config=RunConfig(
+            previous_run_id=pipeline_result.run_id,
+            step_keys_to_execute=['add_one.compute', 'add_one_2.compute'],
+        ),
+        instance=instance,
+    )
+
+    assert reexecution_result.success
+    assert reexecution_result.result_for_solid('return_one').output_value() == None
+    assert reexecution_result.result_for_solid('add_one_2').output_value() == 3
+
+
+def test_optional():
+    @solid(output_defs=[OutputDefinition(Int, 'x'), OutputDefinition(Int, 'y', is_required=False)])
+    def return_optional(_context):
+        yield Output(1, 'x')
+
+    @lambda_solid
+    def echo(x):
+        return x
+
+    @pipeline
+    def opt_pipeline():
+        x, y = return_optional()
+        echo.alias('echo_x')(x)
+        echo.alias('echo_y')(y)
+
+    pipeline_result = execute_pipeline(opt_pipeline)
+    assert pipeline_result.success
+
+    result_required = pipeline_result.result_for_solid('echo_x')
+    assert result_required.success
+
+    result_optional = pipeline_result.result_for_solid('echo_y')
+    assert not result_optional.success
+    assert result_optional.skipped
+
+
+def test_basic_pipeline_selector():
+    @solid
+    def def_one(_):
+        pass
+
+    # dsl subsets the definitions appropriately
+    @pipeline
+    def pipe():
+        def_one()
+
+    assert pipe.selector.solid_subset == None
+
+
+def test_selector_with_partial_dependency_dict():
+    executed = {}
+
+    @solid
+    def def_one(_):
+        executed['one'] = True
+
+    @solid
+    def def_two(_):
+        executed['two'] = True
+
+    pipe_two = PipelineDefinition(
+        name='pipe_two', solid_defs=[def_one, def_two], dependencies={'def_one': {}}
+    )
+
+    execute_pipeline(pipe_two)
+
+    # if it is in solid defs it will execute even if it is not in dependencies dictionary
+    assert set(executed.keys()) == {'one', 'two'}
+
+
+def test_selector_with_build_sub_pipeline():
+    @solid
+    def def_one(_):
+        pass
+
+    @solid
+    def def_two(_):
+        pass
+
+    # dsl subsets the definitions appropriately
+    @pipeline
+    def pipe():
+        def_one()
+        def_two()
+
+    assert set(pipe.build_sub_pipeline(['def_two']).selector.solid_subset) == {'def_two'}
