@@ -1,18 +1,27 @@
 from dagster import (
+    DagsterEventType,
+    DagsterResourceFunctionError,
+    ExecutionTargetHandle,
     Field,
+    Int,
     ModeDefinition,
     PipelineDefinition,
     ResourceDefinition,
     String,
     execute_pipeline,
+    execute_pipeline_iterator,
     resource,
     solid,
 )
+from dagster.core.execution.api import create_execution_plan, execute_plan
+from dagster.core.instance import DagsterInstance
+from dagster.core.storage.pipeline_run import PipelineRun
+from dagster.core.utils import make_new_run_id
 
 
 def define_string_resource():
     return ResourceDefinition(
-        config_field=Field(String), resource_fn=lambda init_context: init_context.resource_config
+        config=String, resource_fn=lambda init_context: init_context.resource_config
     )
 
 
@@ -47,7 +56,7 @@ def test_yield_resource():
     def _do_resource(init_context):
         yield init_context.resource_config
 
-    yield_string_resource = ResourceDefinition(config_field=Field(String), resource_fn=_do_resource)
+    yield_string_resource = ResourceDefinition(config=String, resource_fn=_do_resource)
 
     pipeline_def = PipelineDefinition(
         name='with_a_yield_resource',
@@ -77,7 +86,7 @@ def test_yield_multiple_resources():
         yield init_context.resource_config
         saw.append('after yield ' + init_context.resource_config)
 
-    yield_string_resource = ResourceDefinition(config_field=Field(String), resource_fn=_do_resource)
+    yield_string_resource = ResourceDefinition(config=String, resource_fn=_do_resource)
 
     pipeline_def = PipelineDefinition(
         name='with_yield_resources',
@@ -118,7 +127,8 @@ def test_resource_decorator():
         assert context.resources.string_one == 'foo'
         assert context.resources.string_two == 'bar'
 
-    @resource(config_field=Field(String))
+    # API red alert. One has to wrap a type in Field because it is callable
+    @resource(config=Field(String))
     def yielding_string_resource(init_context):
         saw.append('before yield ' + init_context.resource_config)
         yield init_context.resource_config
@@ -168,17 +178,13 @@ def test_mixed_multiple_resources():
         yield init_context.resource_config
         saw.append('after yield ' + init_context.resource_config)
 
-    yield_string_resource = ResourceDefinition(
-        config_field=Field(String), resource_fn=_do_yield_resource
-    )
+    yield_string_resource = ResourceDefinition(config=String, resource_fn=_do_yield_resource)
 
     def _do_return_resource(init_context):
         saw.append('before return ' + init_context.resource_config)
         return init_context.resource_config
 
-    return_string_resource = ResourceDefinition(
-        config_field=Field(String), resource_fn=_do_return_resource
-    )
+    return_string_resource = ResourceDefinition(config=String, resource_fn=_do_return_resource)
 
     pipeline_def = PipelineDefinition(
         name='with_a_yield_resource',
@@ -416,3 +422,265 @@ def test_stacked_resource_cleanup():
     execute_pipeline(pipeline)
 
     assert called == ['creation_1', 'creation_2', 'solid', 'cleanup_2', 'cleanup_1']
+
+
+def test_resource_init_failure():
+    @resource
+    def failing_resource(_init_context):
+        raise Exception('Uh oh')
+
+    @solid(required_resource_keys={'failing_resource'})
+    def failing_resource_solid(_context):
+        pass
+
+    pipeline = PipelineDefinition(
+        name='test_resource_init_failure',
+        solid_defs=[failing_resource_solid],
+        mode_defs=[ModeDefinition(resource_defs={'failing_resource': failing_resource})],
+    )
+
+    res = execute_pipeline(pipeline, raise_on_error=False)
+
+    event_types = [event.event_type_value for event in res.event_list]
+    assert DagsterEventType.PIPELINE_INIT_FAILURE.value in event_types
+
+    execution_plan = create_execution_plan(pipeline)
+    run_id = make_new_run_id()
+    pipeline_run = PipelineRun.create_empty_run(pipeline.name, run_id)
+
+    step_events = execute_plan(
+        execution_plan, pipeline_run=pipeline_run, instance=DagsterInstance.ephemeral()
+    )
+
+    event_types = [event.event_type_value for event in step_events]
+    assert DagsterEventType.PIPELINE_INIT_FAILURE.value in event_types
+
+    # Test the pipeline init failure event fires even if we are raising errors
+    events = []
+    try:
+        for event in execute_pipeline_iterator(pipeline):
+            events.append(event)
+    except DagsterResourceFunctionError:
+        pass
+
+    event_types = [event.event_type_value for event in events]
+    assert DagsterEventType.PIPELINE_INIT_FAILURE.value in event_types
+
+
+def test_dagster_type_resource_decorator_config():
+    @resource(Int)
+    def dagster_type_resource_config(_):
+        raise Exception('not called')
+
+    assert dagster_type_resource_config.config_field.config_type.given_name == 'Int'
+
+    @resource(int)
+    def python_type_resource_config(_):
+        raise Exception('not called')
+
+    assert python_type_resource_config.config_field.config_type.given_name == 'Int'
+
+
+def test_resource_init_failure_with_teardown():
+    called = []
+    cleaned = []
+
+    @resource
+    def resource_a(_):
+        try:
+            called.append('A')
+            yield 'A'
+        finally:
+            cleaned.append('A')
+
+    @resource
+    def resource_b(_):
+        try:
+            called.append('B')
+            raise Exception('uh oh')
+            yield 'B'  # pylint: disable=unreachable
+        finally:
+            cleaned.append('B')
+
+    @solid(required_resource_keys={'a', 'b'})
+    def resource_solid(_):
+        pass
+
+    pipeline = PipelineDefinition(
+        name='test_resource_init_failure_with_cleanup',
+        solid_defs=[resource_solid],
+        mode_defs=[ModeDefinition(resource_defs={'a': resource_a, 'b': resource_b})],
+    )
+
+    res = execute_pipeline(pipeline, raise_on_error=False)
+    event_types = [event.event_type_value for event in res.event_list]
+    assert DagsterEventType.PIPELINE_INIT_FAILURE.value in event_types
+
+    assert called == ['A', 'B']
+    assert cleaned == ['B', 'A']
+
+    called = []
+    cleaned = []
+
+    events = []
+    try:
+        for event in execute_pipeline_iterator(pipeline):
+            events.append(event)
+    except DagsterResourceFunctionError:
+        pass
+
+    event_types = [event.event_type_value for event in events]
+    assert DagsterEventType.PIPELINE_INIT_FAILURE.value in event_types
+    assert called == ['A', 'B']
+    assert cleaned == ['B', 'A']
+
+
+def test_solid_failure_resource_teardown():
+    called = []
+    cleaned = []
+
+    @resource
+    def resource_a(_):
+        try:
+            called.append('A')
+            yield 'A'
+        finally:
+            cleaned.append('A')
+
+    @resource
+    def resource_b(_):
+        try:
+            called.append('B')
+            yield 'B'
+        finally:
+            cleaned.append('B')
+
+    @solid(required_resource_keys={'a', 'b'})
+    def resource_solid(_):
+        raise Exception('uh oh')
+
+    pipeline = PipelineDefinition(
+        name='test_solid_failure_resource_teardown',
+        solid_defs=[resource_solid],
+        mode_defs=[ModeDefinition(resource_defs={'a': resource_a, 'b': resource_b})],
+    )
+
+    res = execute_pipeline(pipeline, raise_on_error=False)
+    assert res.event_list[-1].event_type_value == 'PIPELINE_FAILURE'
+    assert called == ['A', 'B']
+    assert cleaned == ['B', 'A']
+
+    called = []
+    cleaned = []
+
+    events = []
+    try:
+        for event in execute_pipeline_iterator(pipeline):
+            events.append(event)
+    except DagsterResourceFunctionError:
+        pass
+
+    assert len(events) > 1
+    assert events[-1].event_type_value == 'PIPELINE_FAILURE'
+    assert called == ['A', 'B']
+    assert cleaned == ['B', 'A']
+
+
+def test_resource_teardown_failure():
+    called = []
+    cleaned = []
+
+    @resource
+    def resource_a(_):
+        try:
+            called.append('A')
+            yield 'A'
+        finally:
+            cleaned.append('A')
+
+    @resource
+    def resource_b(_):
+        try:
+            called.append('B')
+            yield 'B'
+        finally:
+            raise Exception('uh oh')
+            cleaned.append('B')  # pylint: disable=unreachable
+
+    @solid(required_resource_keys={'a', 'b'})
+    def resource_solid(_):
+        pass
+
+    pipeline = PipelineDefinition(
+        name='test_resource_teardown_failure',
+        solid_defs=[resource_solid],
+        mode_defs=[ModeDefinition(resource_defs={'a': resource_a, 'b': resource_b})],
+    )
+
+    result = execute_pipeline(pipeline, raise_on_error=False)
+    assert result.success
+    error_events = [
+        event
+        for event in result.event_list
+        if event.is_engine_event and event.event_specific_data.error
+    ]
+    assert len(error_events) == 1
+    assert called == ['A', 'B']
+    assert cleaned == ['A']
+
+    called = []
+    cleaned = []
+    events = []
+    try:
+        for event in execute_pipeline_iterator(pipeline):
+            events.append(event)
+    except DagsterResourceFunctionError:
+        pass
+
+    assert called == ['A', 'B']
+    assert cleaned == ['A']
+
+
+def define_resource_teardown_failure_pipeline():
+    @resource
+    def resource_a(_):
+        try:
+            yield 'A'
+        finally:
+            pass
+
+    @resource
+    def resource_b(_):
+        try:
+            yield 'B'
+        finally:
+            raise Exception('uh oh')
+
+    @solid(required_resource_keys={'a', 'b'})
+    def resource_solid(_):
+        pass
+
+    return PipelineDefinition(
+        name='resource_teardown_failure',
+        solid_defs=[resource_solid],
+        mode_defs=[ModeDefinition(resource_defs={'a': resource_a, 'b': resource_b})],
+    )
+
+
+def test_multiprocessing_resource_teardown_failure():
+    pipeline = ExecutionTargetHandle.for_pipeline_python_file(
+        __file__, 'define_resource_teardown_failure_pipeline'
+    ).build_pipeline_definition()
+    result = execute_pipeline(
+        pipeline,
+        environment_dict={'storage': {'filesystem': {}}, 'execution': {'multiprocess': {}}},
+        instance=DagsterInstance.local_temp(),
+        raise_on_error=False,
+    )
+    assert result.success
+    error_events = [
+        event
+        for event in result.event_list
+        if event.is_engine_event and event.event_specific_data.error
+    ]
+    assert len(error_events) > 1
